Learn R Programming

experiment (version 1.0-0)

ATEnocov: Estimation of the Average Treatment Effect in Randomized Experiments

Description

This function computes the standard ``difference-in-means'' estimate of the average treatment effect in randomized experiments without using pre-treatment covariates. The treatment variable is assumed to be binary. Currently, the two designs are allowed: complete randomized design and matched-pair design.

Usage

ATEnocov(Y, Z, data = parent.frame(), match = NULL)

Arguments

Y
The outcome variable of interest.
Z
The (randomized) treatment variable. This variable should be binary.
data
A data frame containing the relevant variables.
match
A variable indicating matched-pairs. The two units in the same matched-pair should have the same value.

Value

  • A list of class ATEnocov which contains the following items:
  • callThe matched call.
  • YThe outcome variable.
  • ZThe treatment variable.
  • matchThe matched-pair indicator variable.
  • ATEestThe estimated average treatment effect.
  • ATE.varThe estimated variance of the average treatment effect estimator.
  • diffWithin-pair differences if the matched-pair design is analyzed.

References

Imai, Kosuke, (2007). Randomization-based Inference and Efficiency Analysis in Experiments under the Matched-Pair Design, Technical Report. Department of Politics, Princeton University.